Module borsh

Module borsh 

Borsh utils

Functions

get_instance_packed_len
Get the packed length for the serialized form of this object instance.
get_packed_len
Get the worst-case packed length for the given BorshSchema
try_from_slice_unchecked
Deserializes without checking that the entire slice has been consumed