Module gemachain_program::message[][src]

A library for generating a message from a sequence of instructions

Re-exports

pub use legacy::Message;

Modules

A library for generating a message from a sequence of instructions

Structs

Collection of mapped addresses loaded succinctly by a transaction using on-chain address map accounts.

Combination of a version #0 message and its mapped addresses

Enums

Sanitized message of a transaction which includes a set of atomic instructions to be executed on-chain

Message versions supported by the Gemachain runtime.

Constants

The length of a message header in bytes

Bit mask that indicates whether a serialized message is versioned.