Struct gemachain_program::message::MappedMessage[][src]

pub struct MappedMessage {
    pub message: Message,
    pub mapped_addresses: MappedAddresses,
}
Combination of a version #0 message and its mapped addresses

Fields

message: Message

Message which loaded a collection of mapped addresses

mapped_addresses: MappedAddresses

Collection of mapped addresses loaded by this message

Implementations

Returns the total length of loaded accounts for this message

Iterator for the addresses of the loaded accounts for this message

Returns true if any account keys are duplicates

Returns the address of the account at the specified index of the list of message account keys constructed from unmapped keys, followed by mapped writable addresses, and lastly the list of mapped readonly addresses.

Returns true if the account at the specified index was loaded as writable

Returns true if the account at the specified index is called as a program by an instruction