Module gemachain_program::message::v0[][src]

Structs

Indexes that are mapped to addresses using an on-chain address map for succinctly loading readonly and writable accounts.

Transaction message format which supports succinct account loading with indexes for on-chain address maps.