Module slot_hashes

Module slot_hashes 

named accounts for synthesized data accounts for bank state, etc.

this account carries the Bank’s most recent bank hashes for some N parents

Re-exports

pub use crate::clock::Slot;

Structs

SlotHashes

Constants

MAX_ENTRIES

Type Aliases

SlotHash