pub struct IterItem<'a>(pub u64, pub &'a Hash, pub &'a FeeCalculator);๐Deprecated since 1.8.0:
Please do not use, will no longer be available in the future
Tuple Fields
0: u64๐Deprecated since 1.8.0:
Please do not use, will no longer be available in the future
1: &'a Hash๐Deprecated since 1.8.0:
Please do not use, will no longer be available in the future
2: &'a FeeCalculator๐Deprecated since 1.8.0:
Please do not use, will no longer be available in the future