Struct gemachain_program::message::v0::Message [−][src]
pub struct Message {
pub header: MessageHeader,
pub account_keys: Vec<Pubkey>,
pub address_map_indexes: Vec<AddressMapIndexes>,
pub recent_blockhash: Hash,
pub instructions: Vec<CompiledInstruction>,
}Expand description
Transaction message format which supports succinct account loading with indexes for on-chain address maps.
Fields
header: MessageHeaderThe message header, identifying signed and read-only account_keys
account_keys: Vec<Pubkey>List of accounts loaded by this transaction.
address_map_indexes: Vec<AddressMapIndexes>List of address map indexes used to succinctly load additional accounts for this transaction.
Notes
The last address_map_indexes.len() accounts of the read-only unsigned
accounts are loaded as address maps.
recent_blockhash: HashThe blockhash of a recent block.
instructions: Vec<CompiledInstruction>Instructions that invoke a designated program, are executed in sequence, and committed in one atomic transaction if all succeed.
Notes
Account and program indexes will index into the list of addresses
constructed from the concatenation of account_keys, flattened list of
writable address map indexes, and the flattened readonly address
map indexes.
Implementations